@@ -14,6 +14,12 @@ def test_with_documentation():
 
     This is a link to `pytest`_.
 
+    Here is a list:
+
+    1. One
+    2. Two
+    3. Three
+
     .. _`pytest`: https://github.com/pytest-dev/pytest
     """
     pass
